#!/bin/sh

# Copyright (C) 2016-2019 Gigaset Communications GmbH

SRC_DIR_SHARE="/usr/share/vendor/"
SRC_DIR="$SRC_DIR_SHARE"
DEST_DIR="/vendor"

SSL_SRC_DIR="/vendor/factory/ssl"
SSL_DST_DIR="/data/certs/client"

start()
{
	local is_mounted=0
	local readonly=0

	[ -d $SRC_DIR ] || SRC_DIR="/config/vendor/"

	if [ -e $SRC_DIR/vendor/boot/uImage -a -e $SRC_DIR/vendor/boot/uInitramfs ]; then
		mount | grep vendor > /dev/null && is_mounted=1
		if [ $is_mounted = 0 ]; then
			mkdir -p /vendor
			[ -e /dev/ubi0 ] || ubiattach -m 3 /dev/ubi_ctrl > /dev/null
			mount -t ubifs -o ro,noatime ubi0:vendor /vendor
			[ $? = 0 ] && is_mounted=1
			#mkdir -p $DEST_DIR
		fi

		if [ $is_mounted = 1 ]; then
			mount | grep vendor | grep "(ro" > /dev/null && readonly=1

			if [ -d $DEST_DIR ]; then
				[ $readonly = 1 ] && mount -o remount,rw /vendor
				rsync --exclude="variant_*" --exclude="backup" --exclude="factory" --inplace --delete-before -acv $SRC_DIR $DEST_DIR > /dev/null
				sync
				[ "$SRC_DIR" = "$SRC_DIR_SHARE" ] || rm -rf $SRC_DIR
				mount -o remount,ro /vendor
			fi
		fi
	fi

	# Copy device specific certificates if any
	ls $SSL_DST_DIR/gigaset_factory_*.pem  > /dev/null 2>&1
	if [ $? -ne 0 -a -d $SSL_SRC_DIR ]; then
		mkdir -p $SSL_DST_DIR
		cp -ar $SSL_SRC_DIR/* $SSL_DST_DIR/
		chmod 644 $SSL_DST_DIR/gigaset_factory_*.pem
		chattr +i $SSL_DST_DIR/gigaset_factory_*.pem
	fi
}

stop()
{
  return 0
}


case "$1" in
  start)
        echo -n "Starting gc-vendor sync "
        start
        echo "done"
        ;;
  stop)
        ;;
  restart)
        $0 stop
        $0 start
        ;;
  *)
        echo "Usage: syslog { start | stop | restart }" >&2
        exit 1
        ;;
esac

exit 0
