#!/bin/sh
#
# Copyright (C) 2018-2019 Gigaset Communications GmbH
#

source /usr/sbin/gigaset-log-functions
source /etc/bootlog.conf

test "$1" == "status" && { log_info "No handler for command 'status'"; exit 0; }

supervisor_timeout=15

ROOTFS_OPTIONS_DIR="/etc/default/rootfs-options"
ROOTFS_OPTIONS_TMPFILE="${BOOTLOG_DIR}/rootfs-options.log"

test "$(ls -A ${ROOTFS_OPTIONS_DIR})" == "" && exit 0

shopt -s nullglob

retval=0
exec 2>${ROOTFS_OPTIONS_TMPFILE}

rootfs_read_write=""
remounted_read_write=""
[ -w / ] && rootfs_read_write="yes" || rootfs_read_write="no"

[ "${rootfs_read_write}" == "no" ] && { mount -o remount,rw / && remounted_read_write="yes"; }
mount /config
mount /data

for filepath in ${ROOTFS_OPTIONS_DIR}/*; do
	log_info "Sourcing ${filepath}"
	$(bash -e ${filepath} 1>&2) && rm ${filepath}
	test $? -ne 0 &&
	{
		log_error "Failed executing ${filepath} with following error message:"
		while read line; do
			log_error "$line"
		done < ${ROOTFS_OPTIONS_TMPFILE}
		retval=1
	}
done

[ "${remounted_read_write}" = "yes" ] && mount -o remount,ro /
umount /config
umount /data

exit ${retval}
