#!/bin/sh
#
# Copyright (C) 2015-2019 Gigaset Communications GmbH
#

source /usr/sbin/gigaset-log-functions

CONFIG_FILE="/etc/firmware-update.conf"
test -f ${CONFIG_FILE} || { log_error "${CONFIG_FILE} does not exist, skipping"; exit 1; }

source ${CONFIG_FILE}

test ${FIRMWARE_UPDATE_DIR} || { log_error "Required variable FIRMWARE_UPDATE_DIR not defined, skipping"; exit 1; }
test ${FIRMWARE_UPDATE_CLEANUP_UTILITY} || { log_error "Required variable FIRMWARE_UPDATE_CLEANUP_UTILITY not defined, skipping"; exit 1; }
test ${FIRMWARE_UPDATE_EXECUTE_UTILITY} || { log_error "Required variable FIRMWARE_UPDATE_EXECUTE_UTILITY not defined, skipping"; exit 1; }
test ${FIRMWARE_UPDATE_LOG_FILE} || { log_error "Required variable FIRMWARE_UPDATE_LOG_FILE not defined, skipping"; exit 1; }

LOG_TAG="firmware-update-tftp"
source /usr/sbin/firmware-update-log-functions

logi "Starting up normal mode TFTP upgrade"

# Execute clean up script before file download
${FIRMWARE_UPDATE_CLEANUP_UTILITY}

# This script is not permitted to log anything to standard output below this point
# due to usage of udpsvd, anything that is written to standard output is immediately
# send via tftp socket, causing bad opcode this will work on UNIX, but not on Windows.
# Please refer to GPMB-3945

# Start downloading file from tftp
tftpd -c ${FIRMWARE_UPDATE_DIR}
if [ $? -eq 0 ]; then
	sync
	# Check update file name
	firmware_file="$(ls ${FIRMWARE_UPDATE_DIR} 2>/dev/null)"
	# Execute firmware update script
	${FIRMWARE_UPDATE_EXECUTE_UTILITY} "${firmware_file}" "${FIRMWARE_UPDATE_DIR}"
fi
