<?php
class images
{
    private $_imagesPath = null;

    public function __construct($isScreenCapture)
    {
        if ($isScreenCapture)
        {
            $this->_imagesPath = WEBUI_SCREEN_CAPTURE_PATH;
            if(!file_exists($this->_imagesPath)) {
                 if (!is_link(WEBUI_SCREEN_CAPTURE_SYMLINK)) {
                    symlink(WEBUI_SCREEN_CAPTURE_PATH, WEBUI_SCREEN_CAPTURE_SYMLINK);
                }
            }
        }
        else
        {
            $this->_imagesPath = WEBUI_IMG_PATH;
            if(!file_exists($this->_imagesPath)) {
                if (!is_link(WEBUI_IMG_PATH)) {
                    symlink(IMAGEUSERPATH, WEBUI_IMG_PATH);
                }
            }
            if(file_exists(WALLPAPERS_PATH) && !file_exists(WEBUI_WALLPAPERS_PATH)) {
                if (!is_link(WEBUI_WALLPAPERS_PATH)) {
                    symlink(WALLPAPERS_PATH,WEBUI_WALLPAPERS_PATH);
                }
            }
        }
    }

    public function uploadImages($_files)
    {
        try
        {
            $result = false;
            $filemanager = new filemanager();
            $filename = null;

            if (($filemanager->sumFilesSize($_files) <= $filemanager->availableStorageSize($this->_imagesPath, MAXALLOCATEDSIZE)))
            {
                if ($filemanager->checkFileCount($this->_imagesPath) <= MAXFILESCOUNT)
                {
                    $result = $filemanager->uploadFile($_files, 'fileoperations::replaceRenameFile',
                        $_filters = array(
                            'SizeFilters' => array(
                                'function' => 'LessThan',
                                'condition' => array(
                                    MAXIMGSIZE
                                )
                            ),
                            'TypeFilters' => unserialize(IMAGESMIMETYPE)
                        ), array(
                            'maxwell' => WEBUI_IMG_PATH
                        ), $filename);

                    if ($result == FILEOK && isset($filename))
                    {
                        $this->cropImage($filename);
                    }
                }
                else
                {
                    $result = FILECOUNT;
                    logger::logSyslogMessage(LOG_WARNING, 'Skipping any further uploads due to user pictures number limit reached');
                }
            }
            else
            {
                $result = ERRFILESIZE;
                logger::logSyslogMessage(LOG_WARNING, 'Skipping any further uploads due to user storage limit reached');
            }
            return $result;
        }
        catch (Exception $ex)
        {
            $exc = new errorexceptionhandler();
            $exc->getException($ex);
            logger::logSyslogMessage(LOG_ERR, $ex);
            return false;
        }
    }

    public function deleteImages($_image = array())
    {
        try
        {
            $deletedfile = 0;
            foreach ($_image as $value)
            {
                if (unlink($this->_imagesPath . DIRECTORY_SEPARATOR . $value))
                {
                    logger::logSyslogMessage(LOG_INFO, 'Deleted user picture ' . $this->_imagesPath . DIRECTORY_SEPARATOR . $value);
                    $deletedfile ++;
                }
                else
                {
                    logger::logSyslogMessage(LOG_ERR, 'Failed deleting user picture ' . $this->_imagesPath . DIRECTORY_SEPARATOR . $value);
                }
            }

            $ret = false;
            if ($deletedfile == count($_image))
            {
                $ret = true;
            }
            return $ret;
        }
        catch (Exception $ex)
        {
            $exc = new errorexceptionhandler();
            $exc->getException($ex);
            logger::logSyslogMessage(LOG_ERR, $ex);
            return false;
        }
    }

    public function getInfoUserImages($_dir, $default = false)
    {
        $return = array();
        if (file_exists($_dir))
        {
            $userfile = array();
            $iter = new DirectoryIterator($_dir);
            foreach ($iter as $file)
            {
                if (! $file->isDot())
                {
                    $userfile[] = array(
                        'fileName' => $file->getFilename(),
                        'size' => $file->getSize(),
                        'default'=> ($default) ? true : false
                    );
                }
            }

            $return = $userfile;
        }

        return $this->sortArray($return);
    }

    private function sortArray($_array)
    {
        $ret = array();
        if (! empty($_array))
        {
            foreach ($_array as $key => $row)
            {
                $ringtones[$key] = $row['fileName'];
            }
            array_multisort($ringtones, SORT_NATURAL, $_array);
            $ret = $_array;
        }
        return $ret;
    }

    private function cropImage($_image)
    {
        try
        {
            $new_width = isMaxwell4() ? 480 : 320;
            $new_height =isMaxwell4() ? 272 : 240;
            $image = @imagecreatefromjpeg($this->_imagesPath . DIRECTORY_SEPARATOR . $_image);
            if (! $image)
            {
                unlink($this->_imagesPath . DIRECTORY_SEPARATOR . $_image);
                return false;
            }
            list ($width, $height) = getimagesize($this->_imagesPath . DIRECTORY_SEPARATOR . $_image);
            $internal_width = intval(($width / $height) * $new_height);
            $internal_height = intval(($height / $width) * $new_width);
            if (($new_width < $new_height) || ($internal_width > ($new_width)))
            {
                $internal_width = $new_width;
            }
            else
            {
                $internal_height = $new_height;
            }
            $background = imagecreatetruecolor($new_width, $new_height);
            $color = imagecolorallocate($background, 0, 0, 0);
            imagefill($background, 0, 0, $color);
            imagecopyresampled($background, $image, intval(($new_width - $internal_width) / 2), intval(($new_height - $internal_height) / 2), 0, 0,
                $internal_width, $internal_height, $width, $height);
            imagejpeg($background, $this->_imagesPath . DIRECTORY_SEPARATOR . $_image);
        }
        catch (Exception $ex)
        {
            $exc = new errorexceptionhandler();
            $exc->getException($ex);
            logger::logSyslogMessage(LOG_ERR, $ex);
            return false;
        }
    }
}
